@@ -186,6 +186,25 @@ class SimulationConfigGenerator(ConfigGenerator):
         self._set(EnergyManagementConfig.SECTION, EnergyManagementConfig.FCR_RESERVE, str(fcr_reserve))
         self._set(EnergyManagementConfig.SECTION, EnergyManagementConfig.SOC_SET, str(soc_set))
 
+    def set_ev_operation_strategy(self, operation_strategy: str, charging_strategy: str, max_power: float) -> None:
+        """
+        Setting Frequency Containment Reserve (FCR) including a Intraday Recharge Strategy (IDM) as the operation strategy
+
+        Parameters
+        ----------
+        charging_strategy :
+            select charging strategy (uncontrolled, ...)
+        max_power :
+            Maximum power to recharge when plugged in
+
+        Returns
+        -------
+
+        """
+        self.set_operation_strategy(operation_strategy)
+        self._set(EnergyManagementConfig.SECTION, EnergyManagementConfig.EV_CHARGING_STRATEGY, charging_strategy)
+        self._set(EnergyManagementConfig.SECTION, EnergyManagementConfig.MAX_POWER, str(max_power))
+
     def set_peak_shaving_strategy(self, strategy: str, max_power: float):
         """
         Setting peak shaving as the operation strategy
@@ -792,6 +811,20 @@ class SimulationConfigGenerator(ConfigGenerator):
         """
         self._set(ProfileConfig.SECTION, ProfileConfig.LOAD_PROFILE, load_profile)
 
+    def set_total_profile_config(self, all_profile_direction, soc_profile, binary_profile) -> None:
+        """
+        Sets parameters for the profile section of the simulation.ini
+        :param technical_profile_direction: name of the profile direction as str
+        :param soc_profile: name of specified soc profile as str
+        :param binary_profile: name of specified binary profile as str
+
+        :return:
+        """
+        self._set(ProfileConfig.SECTION, ProfileConfig.TECHNICAL_PROFILE_DIR, all_profile_direction)
+        self._set(ProfileConfig.SECTION, ProfileConfig.POWER_PROFILE_DIR, all_profile_direction)
+        self._set(ProfileConfig.SECTION, ProfileConfig.SOC_PROFILE, soc_profile)
+        self._set(ProfileConfig.SECTION, ProfileConfig.BINARY_PROFILE, binary_profile)
+
     def set_generation_profile_config(self, generation_profile: str = None) -> None:
         """
         Set the filename for the generation profile
