@@ -22,17 +22,8 @@ class NoCycleDetector(CycleDetector):
     def get_full_equivalent_cycle(self) -> float:
         return 0
 
-    def _update_cycle_steps(self, soc: float, time_passed: float) -> None:
-        pass
-
     def get_mean_soc(self) -> float:
         return 0
 
-    def _reset_cycle(self, soc:float, time_passed: float) -> None:
-        pass
-
     def reset(self) -> None:
         pass
-
-    def close(self) -> None:
-        pass
