@@ -377,8 +377,8 @@ class FileProfile:
             return 1.0
 
     @classmethod
-    def __get_value_unit_from(self, header: dict) -> float:
-        return self.__get_unit_from(header, self.Header.UNIT)
+    def __get_value_unit_from(cls, header: dict) -> float:
+        return cls.__get_unit_from(header, cls.Header.UNIT)
 
     @classmethod
     def __get_time_unit_from(cls, header: dict) -> float:
