@@ -16,5 +16,5 @@ class LoadProfile(FilePowerProfile):
     """Header of load profile for scaling power values"""
 
     def __init__(self, profile_config: ProfileConfig, general_config: GeneralSimulationConfig):
-        super().__init__(general_config, profile_config.load_profile,
+        super().__init__(general_config, profile_config.load_profile_file,
                          scaling_factor=profile_config.load_scaling_factor)
