@@ -1,7 +1,6 @@
 import copy
 import os
 from configparser import ConfigParser
-
 from simses.commons.config.data.energy_management import EnergyManagementDataConfig
 from simses.commons.config.data.power_electronics import PowerElectronicsConfig
 from simses.commons.config.simulation.battery import BatteryConfig
@@ -48,6 +47,7 @@ from simses.system.power_electronics.dcdc_converter.no_loss import NoLossDcDcCon
 from simses.system.power_electronics.electronics import PowerElectronics
 from simses.system.storage_system_ac import StorageSystemAC
 from simses.system.storage_system_dc import StorageSystemDC
+from simses.system.thermal.ambient.user_battery_temperature import UserBatteryTemperatureProfile
 from simses.system.thermal.ambient.ambient_thermal_model import AmbientThermalModel
 from simses.system.thermal.ambient.constant_temperature import ConstantAmbientTemperature
 from simses.system.thermal.ambient.location_temperature import LocationAmbientTemperature
@@ -172,8 +172,8 @@ class StorageSystemFactory:
                                                                  'Following options are available: ' + str(options))
 
     def create_ambient_temperature_model(self) -> AmbientThermalModel:
+        ambient_temperature_model: str = str(self.__system_config.ambient_temperature_model[StorageSystemConfig.AMBIENT_TEMPERATURE_TYPE])
         if self.__system_config.thermal_simulation:
-            ambient_temperature_model: str = str(self.__system_config.ambient_temperature_model[StorageSystemConfig.AMBIENT_TEMPERATURE_TYPE])
             if ambient_temperature_model == ConstantAmbientTemperature.__name__:
                 self.__log.debug('Creating ambient temperature model as ' + ambient_temperature_model)
                 try:
@@ -191,11 +191,15 @@ class StorageSystemFactory:
                 options.append(ConstantAmbientTemperature.__name__)
                 options.append(LocationAmbientTemperature.__name__)
                 raise Exception('Ambient temperature model ' + ambient_temperature_model + ' is unknown. '
-                                                                                           'Following options are available: ' + str(
-                    options))
+                                'Following options are available: ' + str(options))
         else:
-            self.__log.debug('Creating ambient temperature model as ' + ConstantAmbientTemperature.__name__ + ' with default value of constant ambient temperature = 25°C.')
-            return ConstantAmbientTemperature()
+            if ambient_temperature_model == UserBatteryTemperatureProfile.__name__:
+                self.__log.debug('Creating ambient temperature model as ' + ambient_temperature_model)
+                return UserBatteryTemperatureProfile(self.__profile_config, self.__general_config)
+            else:
+                self.__log.debug('Creating ambient temperature model as ' + ConstantAmbientTemperature.__name__ +
+                                 ' with default value of constant ambient temperature = 25°C.')
+                return ConstantAmbientTemperature()
 
     def create_solar_irradiation_model(self, housing: Housing) -> SolarIrradiationModel:
         if self.__system_config.thermal_simulation:
@@ -245,7 +249,7 @@ class StorageSystemFactory:
                                 'or contact the SimSES Development Team.')
         else:
             self.__log.debug('Creating thermal model for cell type ' + NoSystemThermalModel.__class__.__name__)
-            return NoSystemThermalModel(ambient_thermal_model, self.__general_config)
+            return NoSystemThermalModel(ambient_thermal_model, self.__general_config, dc_systems)
 
     def create_housing_from(self, housing_name: str, ambient_thermal_model: AmbientThermalModel) -> Housing:
         if self.__system_config.thermal_simulation:
@@ -311,7 +315,7 @@ class StorageSystemFactory:
     def create_system_state_from(self, system_id, storage_id) -> SystemState:
         state = SystemState(system_id, storage_id)
         state.set(SystemState.TIME, self.__general_config.start)
-        state.set(SystemState.FULFILLMENT, 1.0)
+        state.set(SystemState.AC_FULFILLMENT, 1.0)
         return state
 
     def create_power_distributor_ac(self) -> PowerDistributor:
